@@ -238,3 +238,14 @@ def createCheckBox(parent, layout=None, widget_cls=None, label=None, attr_name=N
     getConnect(connect, chk)
     getAddWidget(parent=parent, layout=layout, widget=chk)
     return chk
+
+def createComponent(parent, layout=None, widget_cls=None, label=None, attr_name=None, connect=None, **kwargs):
+    widget_cls = widget_cls or QTextEdit
+    text = label or "check"
+    addLabel(layout, text)
+    chk = widget_cls()
+    apply_properties(chk, kwargs)
+    getParentAttr(parent, chk, attr_name=attr_name, label=label)
+    getConnect(connect, chk)
+    getAddWidget(parent=parent, layout=layout, widget=chk)
+    return chk
